@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2013 Conrad Sanderson
-// Copyright (C) 2008-2013 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2014 Conrad Sanderson
+// Copyright (C) 2008-2014 NICTA (www.nicta.com.au)
 // Copyright (C) 2011 James Sanders
 // Copyright (C) 2013 Ryan Curtin
 // 
@@ -1197,6 +1197,21 @@ subview<eT>::operator/= (const subview& x_in)
 
 
 
+template<typename eT>
+template<typename T1, typename gen_type>
+inline
+typename enable_if2< is_same_type<typename T1::elem_type, eT>::value, void>::result
+subview<eT>::operator= (const Gen<T1,gen_type>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_assert_same_size(n_rows, n_cols, in.n_rows, in.n_cols, "copy into submatrix");
+  
+  in.apply(*this);
+  }
+
+
+
 //! transform each element in the subview using a functor
 template<typename eT>
 template<typename functor>
@@ -2671,6 +2686,21 @@ subview_col<eT>::operator=(const Base<eT,T1>& X)
 
 
 
+template<typename eT>
+template<typename T1, typename gen_type>
+inline
+typename enable_if2< is_same_type<typename T1::elem_type, eT>::value, void>::result
+subview_col<eT>::operator= (const Gen<T1,gen_type>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_assert_same_size(subview<eT>::n_rows, uword(1), in.n_rows, (in.is_col ? uword(1) : in.n_cols), "copy into submatrix");
+  
+  in.apply(*this);
+  }
+
+
+
 template<typename eT>
 arma_inline
 const Op<subview_col<eT>,op_htrans>
@@ -3003,6 +3033,21 @@ subview_row<eT>::operator=(const Base<eT,T1>& X)
 
 
 
+template<typename eT>
+template<typename T1, typename gen_type>
+inline
+typename enable_if2< is_same_type<typename T1::elem_type, eT>::value, void>::result
+subview_row<eT>::operator= (const Gen<T1,gen_type>& in)
+  {
+  arma_extra_debug_sigprint();
+  
+  arma_debug_assert_same_size(uword(1), subview<eT>::n_cols, (in.is_row ? uword(1) : in.n_rows), in.n_cols, "copy into submatrix");
+  
+  in.apply(*this);
+  }
+
+
+
 template<typename eT>
 arma_inline
 const Op<subview_row<eT>,op_htrans>
